Matrix

Struct Matrix 

pub struct Matrix<Set: Clone> { /* private fields */ }

Implementations

Source

impl<F: MetaType> Matrix<F>

Source

impl<F: MetaType> Matrix<F>

Source

impl<R: MetaType> Matrix<R>

pub fn row_hermite_algorithm(&self) -> (Self, Self, R, Vec<usize>)

pub fn col_hermite_algorithm(&self) -> (Self, Self, R, Vec<usize>)

pub fn det(&self) -> Result<R, MatOppErr>

pub fn rank(&self) -> usize

Source

impl<R: MetaType> Matrix<R>

Source

impl<Set: Clone> Matrix<Set>

pub fn full(rows: usize, cols: usize, elem: &Set) -> Self

pub fn construct( rows: usize, cols: usize, make_entry: impl Fn(usize, usize) -> Set, ) -> Self

Construct a matrix from a closure.

use algebraeon_nzq::Integer;
use algebraeon_rings::matrix::Matrix;
let a = Matrix::<Integer>::construct(2, 3, |r, c| if (r + c) % 2 == 0 { Integer::ZERO } else { Integer::ONE });
let b = Matrix::<Integer>::from_rows(
    vec![
        vec![Integer::ZERO, Integer::ONE, Integer::ZERO],
        vec![Integer::ONE, Integer::ZERO, Integer::ONE]
    ]
);
assert_eq!(a, b);
pub fn from_rows(rows_elems: Vec<Vec<impl Into<Set> + Clone>>) -> Self

Construct a matrix from a list of rows.

pub fn from_cols(cols_elems: Vec<Vec<impl Into<Set> + Clone>>) -> Self

Construct a matrix from a list of columns.

pub fn from_row(elems: Vec<impl Into<Set> + Clone>) -> Self

Construct a matrix from a row.

pub fn from_col(elems: Vec<impl Into<Set> + Clone>) -> Self

Construct a matrix from a column.

pub fn at(&self, r: usize, c: usize) -> Result<&Set, MatOppErr>

Get a reference to the entry at row r and column c.

pub fn at_mut(&mut self, r: usize, c: usize) -> Result<&mut Set, MatOppErr>

Get a mutable reference to the entry at row r and column c.

pub fn rows(&self) -> usize

pub fn cols(&self) -> usize

pub fn submatrix(&self, rows: Vec<usize>, cols: Vec<usize>) -> Self

Return the submatrix given by the intersection of the rows defined by rows and the columns defined by cols.

pub fn get_row_submatrix(&self, row: usize) -> Self

pub fn get_col_submatrix(&self, col: usize) -> Self

pub fn get_row_refs(&self, row: usize) -> Vec<&Set>

pub fn get_col_refs(&self, col: usize) -> Vec<&Set>

pub fn get_row(&self, row: usize) -> Vec<Set>

pub fn get_col(&self, col: usize) -> Vec<Set>

pub fn apply_map<NewSet: Clone>( &self, f: impl Fn(&Set) -> NewSet, ) -> Matrix<NewSet>

Apply a function f to the entries of this matrix, producing a new matrix.

pub fn transpose(self) -> Self

pub fn transpose_ref(&self) -> Self

pub fn transpose_mut(&mut self)

pub fn flip_rows(self) -> Self

pub fn flip_rows_ref(&self) -> Self

pub fn flip_rows_mut(&mut self)

pub fn flip_cols(self) -> Self

pub fn flip_cols_ref(&self) -> Self

pub fn flip_cols_mut(&mut self)

pub fn join_rows<MatT: Borrow<Matrix<Set>>>( cols: usize, mats: Vec<MatT>, ) -> Matrix<Set>

Concatenate the rows of the matrices in mats into a single matrix.

cols must match the number of columns of every matrix in mats. The purpose of this input is to produce an empty matrix of the correct dimension when mats is empty.

Panics

This function panics if cols does not match the number of columns of every matrix in mats.

pub fn join_cols<MatT: Borrow<Matrix<Set>>>( rows: usize, mats: Vec<MatT>, ) -> Matrix<Set>

Concatenate the columns of the matrices in mats into a single matrix.

rows must match the number of rows of every matrix in mats. The purpose of this input is to produce an empty matrix of the correct dimension when mats is empty.

Panics

This function panics if rows does not match the number of rows of every matrix in mats.

pub fn entries_list(&self) -> Vec<&Set>

Return a vector containing the entries of this matrix.

Most useful when this matrix is a row vector or a column vector.

Source

impl<R: MetaType> Matrix<R>

pub fn pprint(&self)

Source

impl<R: MetaType> Matrix<R>

pub fn zero(rows: usize, cols: usize) -> Self

pub fn ident(n: usize) -> Self

pub fn diag(diag: &[R]) -> Self

pub fn dot(a: &Self, b: &Self) -> R

pub fn add_mut(&mut self, b: &Self) -> Result<(), MatOppErr>

pub fn add(a: &Self, b: &Self) -> Result<Self, MatOppErr>

pub fn neg_mut(&mut self)

pub fn neg(&self) -> Self

pub fn mul(a: &Self, b: &Self) -> Result<Self, MatOppErr>

pub fn apply_row(&self, row: &[R]) -> Vec<R>

pub fn apply_col(&self, col: &[R]) -> Vec<R>

pub fn mul_scalar(&self, scalar: &R) -> Matrix<R>

pub fn mul_scalar_ref(&self, scalar: &R) -> Matrix<R>

pub fn det_naive(&self) -> Result<R, MatOppErr>

pub fn trace(&self) -> Result<R, MatOppErr>

Source

impl<F: MetaType> Matrix<F>

Source

impl<R: MetaType> Matrix<R>

pub fn factor_primitive(self) -> Option<(R, Matrix<R>)>

pub fn primitive_part(self) -> Option<Matrix<R>>

Source

impl<Field: MetaType> Matrix<Field>

pub fn factor_primitive_fof(&self) -> (Field, Matrix<Integer>)

Source

impl<R: MetaType> Matrix<R>

pub fn smith_algorithm(&self) -> (Self, Self, Self, usize)