FreeModuleOverOrderedSetStructure

Struct FreeModuleOverOrderedSetStructure 

pub struct FreeModuleOverOrderedSetStructure<Set: OrdSignature, SetB: BorrowedStructure<Set>, Ring: SemiRingSignature, RingB: BorrowedStructure<Ring>> { /* private fields */ }

Implementations

Source

impl<Set: OrdSignature, SetB: BorrowedStructure<Set>, Ring: SemiRingSignature + EqSignature, RingB: BorrowedStructure<Ring>> FreeModuleOverOrderedSetStructure<Set, SetB, Ring, RingB>

pub fn new(set: SetB, ring: RingB) -> Self

pub fn set(&self) -> &Set

pub fn collapse_terms( &self, v: <Self as SetSignature>::Set, ) -> <Self as SetSignature>::Set

Input: vector of (Set, Ring) Output: vector of (Set, Ring) which is

  • ordered
  • has no duplicate set elements
  • has no ring elements equal to 0

and is equal to the sum of the input vectors terms. In other words, the returned vector will pass self.is_element(..)