FactoringStructure

Struct FactoringStructure 

pub struct FactoringStructure<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> { /* private fields */ }

Implementations

Source

impl<FS: FiniteFieldSignature, FSB: BorrowedStructure<FS>, FSPB: BorrowedStructure<PolynomialStructure<FS, FSB>>, NB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<PolynomialStructure<FS, FSB>, FSPB, NaturalCanonicalStructure, NB>

Source

impl<ObjectB: BorrowedStructure<NaturalCanonicalStructure>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<NaturalCanonicalStructure, ObjectB, NaturalCanonicalStructure, ExponentB>

Source

impl<PowersB: BorrowedStructure<NaturalCanonicalStructure>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<NaturalCanonicalStructure, PowersB, NaturalCanonicalStructure, ExponentB>

pub fn is_primitive_root( &self, x: &Natural, n_factored: &Factored<Natural, Natural>, ) -> IsPrimitiveRootResult

Return whether x is a primitive root modulo the factorized value

Source

impl<RS: FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure> + EuclideanDomainSignature + GreatestCommonDivisorSignature, RSB: BorrowedStructure<RS>, RSQB: BorrowedStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>>, RSQPB: BorrowedStructure<PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>>, NB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>, RSQPB, NaturalCanonicalStructure, NB>

pub fn into_hensel_factorization( &self, a: NonZeroFactored<Polynomial<RS::Set>, Natural>, h: Polynomial<RS::Set>, ) -> Option<HenselFactorization<true, RS>>

If the polynomial is squarefree return a hensel factorization, otherwise return None

Source

impl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> FactoringStructure<Object, ObjectB, Exponent, ExponentB>

pub fn new(objects: ObjectB, exponents: ExponentB) -> Self

pub fn objects(&self) -> &Object

pub fn exponents(&self) -> &Exponent

Source

impl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> FactoringStructure<Object, ObjectB, Exponent, ExponentB>

pub fn new_irreducible_unchecked( &self, p: Object::Set, ) -> Factored<Object::Set, Exponent::Set>

pub fn new_unit_unchecked( &self, unit: Object::Set, ) -> Factored<Object::Set, Exponent::Set>

pub fn new_powers_unchecked( &self, powers: Vec<(Object::Set, Exponent::Set)>, ) -> Factored<Object::Set, Exponent::Set>

pub fn new_unit_and_powers_unchecked( &self, unit: Object::Set, powers: Vec<(Object::Set, Exponent::Set)>, ) -> Factored<Object::Set, Exponent::Set>

pub fn gcd( &self, a: &Factored<Object::Set, Exponent::Set>, b: &Factored<Object::Set, Exponent::Set>, ) -> Factored<Object::Set, Exponent::Set>

pub fn lcm( &self, a: &Factored<Object::Set, Exponent::Set>, b: &Factored<Object::Set, Exponent::Set>, ) -> Option<Factored<Object::Set, Exponent::Set>>

pub fn is_irreducible(&self, a: &Factored<Object::Set, Exponent::Set>) -> bool

pub fn expand(&self, a: &Factored<Object::Set, Exponent::Set>) -> Object::Set

pub fn expand_squarefree( &self, a: &Factored<Object::Set, Exponent::Set>, ) -> Object::Set

pub fn pow( &self, f: &Factored<Object::Set, Exponent::Set>, n: &Exponent::Set, ) -> Factored<Object::Set, Exponent::Set>

Source

impl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = NaturalCanonicalStructure>, ObjectB: BorrowedStructure<Object>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<Object, ObjectB, NaturalCanonicalStructure, ExponentB>

pub fn divisors<'a>( &'a self, a: &'a Factored<Object::Set, Natural>, ) -> Option<Box<dyn Iterator<Item = Object::Set> + 'a>>

Return an iterator over all divisors of a factorization

pub fn count_divideisors( &self, a: &Factored<Object::Set, Natural>, ) -> Option<Natural>

The number of divisors of a factorization