pub struct FactoringStructure<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> { /* private fields */ }Implementations
Sourceimpl<FS: FiniteFieldSignature, FSB: BorrowedStructure<FS>, FSPB: BorrowedStructure<PolynomialStructure<FS, FSB>>, NB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<PolynomialStructure<FS, FSB>, FSPB, NaturalCanonicalStructure, NB>where
PolynomialStructure<FS, FSB>: SetSignature<Set = Polynomial<FS::Set>> + FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure>,
impl<FS: FiniteFieldSignature, FSB: BorrowedStructure<FS>, FSPB: BorrowedStructure<PolynomialStructure<FS, FSB>>, NB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<PolynomialStructure<FS, FSB>, FSPB, NaturalCanonicalStructure, NB>where
PolynomialStructure<FS, FSB>: SetSignature<Set = Polynomial<FS::Set>> + FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure>,
pub fn into_distinct_degree_factored( &self, a: NonZeroFactored<Polynomial<FS::Set>, Natural>, ) -> DistinctDegreeFactored<FS, FSB>
Sourceimpl<ObjectB: BorrowedStructure<NaturalCanonicalStructure>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<NaturalCanonicalStructure, ObjectB, NaturalCanonicalStructure, ExponentB>
impl<ObjectB: BorrowedStructure<NaturalCanonicalStructure>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<NaturalCanonicalStructure, ObjectB, NaturalCanonicalStructure, ExponentB>
Sourceimpl<PowersB: BorrowedStructure<NaturalCanonicalStructure>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<NaturalCanonicalStructure, PowersB, NaturalCanonicalStructure, ExponentB>
impl<PowersB: BorrowedStructure<NaturalCanonicalStructure>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<NaturalCanonicalStructure, PowersB, NaturalCanonicalStructure, ExponentB>
Sourcepub fn is_primitive_root(
&self,
x: &Natural,
n_factored: &Factored<Natural, Natural>,
) -> IsPrimitiveRootResult
pub fn is_primitive_root( &self, x: &Natural, n_factored: &Factored<Natural, Natural>, ) -> IsPrimitiveRootResult
Return whether x is a primitive root modulo the factorized value
Sourceimpl<RS: FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure> + EuclideanDomainSignature + GreatestCommonDivisorSignature, RSB: BorrowedStructure<RS>, RSQB: BorrowedStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>>, RSQPB: BorrowedStructure<PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>>, NB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>, RSQPB, NaturalCanonicalStructure, NB>where
PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>: SetSignature<Set = Polynomial<RS::Set>> + FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure>,
impl<RS: FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure> + EuclideanDomainSignature + GreatestCommonDivisorSignature, RSB: BorrowedStructure<RS>, RSQB: BorrowedStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>>, RSQPB: BorrowedStructure<PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>>, NB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>, RSQPB, NaturalCanonicalStructure, NB>where
PolynomialStructure<EuclideanRemainderQuotientStructure<RS, RSB, true>, RSQB>: SetSignature<Set = Polynomial<RS::Set>> + FactoringMonoidSignature<FactoredExponent = NaturalCanonicalStructure>,
Sourcepub fn into_hensel_factorization(
&self,
a: NonZeroFactored<Polynomial<RS::Set>, Natural>,
h: Polynomial<RS::Set>,
) -> Option<HenselFactorization<true, RS>>where
RS: EuclideanDomainSignature + GreatestCommonDivisorSignature,
pub fn into_hensel_factorization(
&self,
a: NonZeroFactored<Polynomial<RS::Set>, Natural>,
h: Polynomial<RS::Set>,
) -> Option<HenselFactorization<true, RS>>where
RS: EuclideanDomainSignature + GreatestCommonDivisorSignature,
If the polynomial is squarefree return a hensel factorization, otherwise return None
Sourceimpl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> FactoringStructure<Object, ObjectB, Exponent, ExponentB>
impl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> FactoringStructure<Object, ObjectB, Exponent, ExponentB>
Sourceimpl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> FactoringStructure<Object, ObjectB, Exponent, ExponentB>
impl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = Exponent>, ObjectB: BorrowedStructure<Object>, Exponent: SemiRingSignature + CancellativeAdditionSignature + OrdSignature, ExponentB: BorrowedStructure<Exponent>> FactoringStructure<Object, ObjectB, Exponent, ExponentB>
pub fn new_irreducible_unchecked( &self, p: Object::Set, ) -> Factored<Object::Set, Exponent::Set>
pub fn new_unit_unchecked( &self, unit: Object::Set, ) -> Factored<Object::Set, Exponent::Set>
pub fn new_powers_unchecked( &self, powers: Vec<(Object::Set, Exponent::Set)>, ) -> Factored<Object::Set, Exponent::Set>
pub fn new_unit_and_powers_unchecked( &self, unit: Object::Set, powers: Vec<(Object::Set, Exponent::Set)>, ) -> Factored<Object::Set, Exponent::Set>
pub fn gcd( &self, a: &Factored<Object::Set, Exponent::Set>, b: &Factored<Object::Set, Exponent::Set>, ) -> Factored<Object::Set, Exponent::Set>
pub fn lcm( &self, a: &Factored<Object::Set, Exponent::Set>, b: &Factored<Object::Set, Exponent::Set>, ) -> Option<Factored<Object::Set, Exponent::Set>>
pub fn is_irreducible(&self, a: &Factored<Object::Set, Exponent::Set>) -> bool
pub fn expand(&self, a: &Factored<Object::Set, Exponent::Set>) -> Object::Set
pub fn expand_squarefree( &self, a: &Factored<Object::Set, Exponent::Set>, ) -> Object::Set
pub fn pow( &self, f: &Factored<Object::Set, Exponent::Set>, n: &Exponent::Set, ) -> Factored<Object::Set, Exponent::Set>
Sourceimpl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = NaturalCanonicalStructure>, ObjectB: BorrowedStructure<Object>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<Object, ObjectB, NaturalCanonicalStructure, ExponentB>
impl<Object: UniqueFactorizationMonoidSignature<FactoredExponent = NaturalCanonicalStructure>, ObjectB: BorrowedStructure<Object>, ExponentB: BorrowedStructure<NaturalCanonicalStructure>> FactoringStructure<Object, ObjectB, NaturalCanonicalStructure, ExponentB>